//+------------------------------------------------------------------+
//|                                 Normalized Volume Oscillator.mq4 |
//|                                                  Vadim Shumiloff |
//|                                                shumiloff@mail.ru |
//+------------------------------------------------------------------+
#property copyright "Vadim Shumiloff"
#property link      "shumiloff@mail.ru"

/*--------------------------------------------------------------------
NVO_v2:

This version of the Normaized Volume Oscillator allows user to display
below average volume bars, or not.  Note that by not showing the below 
average volume bars, this indicator can be 'dragged and dropped' upon 
the MT4 'Volumes' indicator, to provide emphasis.

Also, the previous graduations of 38.2/61.8 are now user changeable,
and have been changed to 33/66.
                                                       - Traderathome
--------------------------------------------------------------------*/

#property indicator_separate_window
#property indicator_buffers 5

#property indicator_color1 MediumBlue  //on black use DarkSlateBlue  // Volumes below average
#property indicator_color2 DarkOrange  //on black use Yellow         // Volumes in 1st graduation over average
#property indicator_color3 DarkGreen   //on black use LimeGreen      // Volumes in 2nd graduation over average
#property indicator_color4 Crimson     //on black use Red            // Volumes in 3rd graduation over average
#property indicator_color5 Black       //on black use White          // Volumes greater than 100% over average

#property indicator_width1 2  
#property indicator_width2 2  
#property indicator_width3 2  
#property indicator_width4 2  
#property indicator_width5 2  

//---- External Inputs
extern int              VolumePeriod        = 10;
extern bool             ShowBelowAvgVolumes = true;
extern string Need_2_numbers_dividing_range = "0-100 into 3 parts (33&66, 25&50 etc)";
extern double Enter_Number_1                = 33;
extern double Enter_Number_2                = 66;

double VolBufferH1[];
double VolBufferH2[];
double VolBufferH3[];
double VolBufferH4[];
double VolBufferH5[];

int init()
   {
   string short_name;

   IndicatorBuffers(5);
   
   SetIndexBuffer(1, VolBufferH1);
   SetIndexStyle(0, DRAW_HISTOGRAM);
   SetIndexBuffer(0, VolBufferH1);

   SetIndexBuffer(2, VolBufferH2);
   SetIndexStyle(1, DRAW_HISTOGRAM);
   SetIndexBuffer(1, VolBufferH2);
  
   SetIndexBuffer(3, VolBufferH3);
   SetIndexStyle(2, DRAW_HISTOGRAM);
   SetIndexBuffer(2, VolBufferH3);

   SetIndexBuffer(4, VolBufferH4);
   SetIndexStyle(3, DRAW_HISTOGRAM);
   SetIndexBuffer(3, VolBufferH4);

   SetIndexBuffer(5, VolBufferH5);
   SetIndexStyle(4, DRAW_HISTOGRAM);
   SetIndexBuffer(4, VolBufferH5);

   short_name="NVO_v2  (" + VolumePeriod + ")";
   IndicatorShortName(short_name);
   //SetIndexLabel(0, short_name);
   SetIndexLabel(0,  NULL);
   SetIndexLabel(1,  NULL); 
   SetIndexLabel(2,  NULL);
   SetIndexLabel(3,  NULL);
   SetIndexLabel(4,  NULL);
   SetIndexLabel(5,  NULL);
   SetIndexLabel(6,  NULL);
   SetIndexLabel(7,  NULL);

   return(0);
   }

int start()
   {
   int counted_bars = IndicatorCounted();

   if (counted_bars < 1)
      for (int i = 1; i <= VolumePeriod; i++) 
         {
         VolBufferH1[Bars-i] = 0;
         VolBufferH2[Bars-i] = 0;
         VolBufferH3[Bars-i] = 0;
         VolBufferH4[Bars-i] = 0;
         VolBufferH5[Bars-i] = 0;
         }

   int limit = Bars - counted_bars;
   if (counted_bars > 0) limit++;
   double nvo = 0;
   
   for(i = 0; i < limit; i++)
      {
      VolBufferH1[i] = 0;
      VolBufferH2[i] = 0;
      VolBufferH3[i] = 0;
      VolBufferH4[i] = 0;
      VolBufferH5[i] = 0;
      
      nvo = NormalizedVolume(i)*100 - 100;
       
      if (nvo <= 0)
      {
         if(ShowBelowAvgVolumes) VolBufferH1[i] = nvo;
         if(ShowBelowAvgVolumes==false) VolBufferH1[i] = 0.25;
      }
      else
      {
         if (nvo < Enter_Number_1)
         {
            VolBufferH2[i] = nvo;
         }
         else
         {
            if (nvo < Enter_Number_2)
            {
               VolBufferH3[i] = nvo;
            }
            else
            {
               if (nvo < 100)
               {
                  VolBufferH4[i] = nvo;
               }
               else VolBufferH5[i] = nvo;
            }
         }
      }
   }

   return(0);
   }

double NormalizedVolume(int i)
   {
   double nv = 0;
   for (int j = i; j < (i+VolumePeriod); j++) nv = nv + Volume[j];
   nv = nv / VolumePeriod;
   return (Volume[i] / nv);
   }